Enum source_map_mappings::Bias
[−]
[src]
#[repr(u32)]pub enum Bias { GreatestLowerBound, LeastUpperBound, }
When doing fuzzy searching, whether to slide the next larger or next smaller mapping from the queried location.
Variants
GreatestLowerBoundSlide to the next smaller mapping.
LeastUpperBoundSlide to the next larger mapping.