Enum source_map_mappings::Error
[−]
[src]
#[repr(u32)]pub enum Error { UnexpectedNegativeNumber, UnexpectedlyBigNumber, VlqUnexpectedEof, VlqInvalidBase64, VlqOverflow, }
Errors that can occur during parsing.
Variants
UnexpectedNegativeNumberThe mappings contained a negative line, column, source index, or name index.
UnexpectedlyBigNumberThe mappings contained a number larger than u32::MAX.
VlqUnexpectedEofReached EOF while in the middle of parsing a VLQ.
VlqInvalidBase64Encountered an invalid base 64 character while parsing a VLQ.
VlqOverflowVLQ encountered a number that, when decoded, would not fit in an i64.